@@ -28,7 +28,7 @@ public class GcParameters {
 
   public static void configure(final TestConfig testConfig) {
     final GcImplementation gcImplementation =
-        GcImplementation.valueOf(System.getProperty("withGc", "CMS"));
+        GcImplementation.valueOf(System.getProperty("benchmark.withGc", "CMS"));
     logger.info("Configuring {} GC.", gcImplementation);
     switch (gcImplementation) {
       case CMS:
@@ -43,9 +43,19 @@ public class GcParameters {
       case Shenandoah:
         configureShenandoah(testConfig);
         break;
+      case Epsilon:
+        configureEpsilon(testConfig);
+        break;
     }
   }
 
+  private static void configureEpsilon(final TestConfig testConfig) {
+    configureGeodeProductJvms(testConfig,
+        "-XX:+UnlockExperimentalVMOptions",
+        "-XX:+UseEpsilonGC",
+        "-XX:+UseNUMA");
+  }
+
   private static void configureShenandoah(final TestConfig testConfig) {
     configureGeodeProductJvms(testConfig,
         "-XX:+UnlockExperimentalVMOptions",
