@@ -15,6 +15,8 @@
 package org.apache.geode.benchmark.tasks;
 
 
+import static org.apache.geode.benchmark.tasks.StartServer.SERVER_CACHE;
+
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.RegionShortcut;
 import org.apache.geode.perftest.Task;
@@ -27,7 +29,7 @@ public class CreatePartitionedRegion implements Task {
 
   @Override
   public void run(TestContext context) throws Exception {
-    Cache cache = (Cache) context.getAttribute("SERVER_CACHE");
+    final Cache cache = (Cache) context.getAttribute(SERVER_CACHE);
     cache.createRegionFactory(RegionShortcut.PARTITION_REDUNDANT).create("region");
   }
 }
