@@ -14,6 +14,8 @@
  */
 package org.apache.geode.benchmark.tasks;
 
+import static org.apache.geode.benchmark.tasks.StartServer.SERVER_CACHE;
+
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.RegionShortcut;
 import org.apache.geode.perftest.Task;
@@ -25,7 +27,7 @@ import org.apache.geode.perftest.TestContext;
 public class CreateReplicatedRegion implements Task {
   @Override
   public void run(TestContext context) throws Exception {
-    Cache cache = (Cache) context.getAttribute("SERVER_CACHE");
+    Cache cache = (Cache) context.getAttribute(SERVER_CACHE);
     cache.createRegionFactory(RegionShortcut.REPLICATE).create("region");
   }
 }
