@@ -14,10 +14,13 @@
  */
 package org.apache.geode.benchmark.tasks;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import java.io.Serializable;
 import java.util.Map;
 
 import benchmark.geode.data.FunctionWithArguments;
+import benchmark.geode.data.Portfolio;
 import org.yardstickframework.BenchmarkConfiguration;
 import org.yardstickframework.BenchmarkDriverAdapter;
 
@@ -27,17 +30,18 @@ import org.apache.geode.cache.client.ClientCache;
 import org.apache.geode.cache.client.ClientCacheFactory;
 import org.apache.geode.cache.execute.Function;
 import org.apache.geode.cache.execute.FunctionService;
-import org.apache.geode.cache.execute.ResultCollector;
 
 public class ExecuteParameterizedFunction extends BenchmarkDriverAdapter implements Serializable {
 
   private final LongRange keyRange;
-  private final Function function;
+  private final boolean isValidationEnabled;
+  private final Function<Long> function;
 
-  private Region region;
+  private Region<Long, Portfolio> region;
 
-  public ExecuteParameterizedFunction(final LongRange keyRange) {
+  public ExecuteParameterizedFunction(final LongRange keyRange, final boolean isValidationEnabled) {
     this.keyRange = keyRange;
+    this.isValidationEnabled = isValidationEnabled;
     function = new FunctionWithArguments();
   }
 
@@ -52,11 +56,16 @@ public class ExecuteParameterizedFunction extends BenchmarkDriverAdapter impleme
   @Override
   public boolean test(Map<Object, Object> ctx) {
     @SuppressWarnings("unchecked")
-    ResultCollector<?, ?> resultCollector = FunctionService
+    final Object result = FunctionService
         .onRegion(region)
         .setArguments(keyRange.random())
-        .execute(function);
-    resultCollector.getResult();
+        .execute(function)
+        .getResult();
+
+    if (isValidationEnabled) {
+      assertThat(result).isInstanceOf(Portfolio.class);
+    }
+
     return true;
   }
 }
