@@ -17,6 +17,8 @@
 
 package org.apache.geode.benchmark.tasks;
 
+import static org.apache.geode.benchmark.tasks.StartServer.SERVER_CACHE;
+
 import org.apache.geode.cache.Cache;
 import org.apache.geode.perftest.Task;
 import org.apache.geode.perftest.TestContext;
@@ -28,7 +30,7 @@ public class StopServer implements Task {
 
   @Override
   public void run(final TestContext context) throws Exception {
-    final Cache cache = (Cache) context.getAttribute("SERVER_CACHE");
+    final Cache cache = (Cache) context.getAttribute(SERVER_CACHE);
     cache.close();
   }
 
