@@ -32,9 +32,9 @@ import org.apache.geode.benchmark.tasks.StopServer;
 import org.apache.geode.perftest.TestConfig;
 
 public class ClientServerTopology extends Topology {
-  private static final int NUM_LOCATORS = 1;
-  private static final int NUM_SERVERS = 2;
-  private static final int NUM_CLIENTS = 1;
+  private static final int NUM_LOCATORS = Integer.getInteger(WITH_LOCATOR_COUNT_PROPERTY, 1);
+  private static final int NUM_SERVERS = Integer.getInteger(WITH_SERVER_COUNT_PROPERTY, 2);
+  private static final int NUM_CLIENTS = Integer.getInteger(WITH_CLIENT_COUNT_PROPERTY, 1);
 
   public static void configure(TestConfig config) {
     role(config, LOCATOR, NUM_LOCATORS);
