@@ -15,57 +15,40 @@
 
 package org.apache.geode.benchmark.parameters;
 
-import static org.apache.geode.benchmark.topology.Roles.CLIENT;
-import static org.apache.geode.benchmark.topology.Roles.LOCATOR;
-import static org.apache.geode.benchmark.topology.Roles.SERVER;
+import static org.apache.geode.benchmark.topology.RoleKinds.GEODE_PRODUCT;
+import static org.apache.geode.benchmark.topology.Roles.rolesFor;
 import static org.assertj.core.api.Assertions.assertThat;
 
-import java.util.Properties;
-
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junitpioneer.jupiter.ClearSystemProperty;
+import org.junitpioneer.jupiter.SetSystemProperty;
 
 import org.apache.geode.perftest.TestConfig;
 
 class HeapParametersTest {
 
-  private static final String WITH_HEAP = "withHeap";
-
-  private Properties systemProperties;
-
-  @BeforeEach
-  public void beforeEach() {
-    systemProperties = (Properties) System.getProperties().clone();
-  }
-
-  @AfterEach
-  public void afterEach() {
-    System.setProperties(systemProperties);
-  }
+  private static final String WITH_HEAP = "benchmark.withHeap";
 
   @Test
+  @ClearSystemProperty(key = WITH_HEAP)
   public void withDefault() {
-    System.clearProperty(WITH_HEAP);
     final TestConfig testConfig = new TestConfig();
     HeapParameters.configure(testConfig);
     assertHeap(testConfig, "8g");
   }
 
   @Test
+  @SetSystemProperty(key = WITH_HEAP, value = "16g")
   public void with16g() {
-    System.setProperty(WITH_HEAP, "16g");
     final TestConfig testConfig = new TestConfig();
     HeapParameters.configure(testConfig);
     assertHeap(testConfig, "16g");
   }
 
   private void assertHeap(final TestConfig testConfig, final String heap) {
-    assertThat(testConfig.getJvmArgs().get(CLIENT.name())).contains("-Xmx" + heap);
-    assertThat(testConfig.getJvmArgs().get(SERVER.name())).contains("-Xmx" + heap);
-    assertThat(testConfig.getJvmArgs().get(LOCATOR.name())).contains("-Xmx" + heap);
-    assertThat(testConfig.getJvmArgs().get(CLIENT.name())).contains("-Xms" + heap);
-    assertThat(testConfig.getJvmArgs().get(SERVER.name())).contains("-Xms" + heap);
-    assertThat(testConfig.getJvmArgs().get(LOCATOR.name())).contains("-Xms" + heap);
+    rolesFor(GEODE_PRODUCT).forEach(role -> {
+      assertThat(testConfig.getJvmArgs().get(role.name())).contains("-Xmx" + heap);
+      assertThat(testConfig.getJvmArgs().get(role.name())).contains("-Xms" + heap);
+    });
   }
 }
