@@ -25,6 +25,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.SSL_TRUSTSTOR
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import java.util.concurrent.CompletableFuture;
 
@@ -36,6 +37,7 @@ import org.apache.geode.perftest.jvms.rmi.ChildJVM;
 
 class JVMLauncher {
   private static final Logger logger = LoggerFactory.getLogger(RemoteJVMFactory.class);
+  public static final String WITH_STRACE = "benchmark.withStrace";
 
   JVMLauncher() {}
 
@@ -53,10 +55,10 @@ class JVMLauncher {
   CompletableFuture<Void> launchWorker(Infrastructure infra, int rmiPort,
       JVMMapping jvmConfig)
       throws UnknownHostException {
-    String[] shellCommand =
-        buildCommand(InetAddress.getLocalHost().getHostAddress(), rmiPort, jvmConfig);
+    final String[] shellCommand = traceCommand(
+        buildCommand(InetAddress.getLocalHost().getHostAddress(), rmiPort, jvmConfig), jvmConfig);
 
-    CompletableFuture<Void> future = new CompletableFuture<Void>();
+    CompletableFuture<Void> future = new CompletableFuture<>();
     Thread thread = new Thread("Worker " + jvmConfig.getNode().getAddress()) {
       public void run() {
 
@@ -80,18 +82,38 @@ class JVMLauncher {
     return future;
   }
 
+  String[] traceCommand(final String[] command, JVMMapping jvmConfig) {
+    List<String> strace = new ArrayList<>();
+
+    if (Boolean.getBoolean(WITH_STRACE)) {
+      strace.add("strace");
+      strace.add("-o");
+      strace.add(jvmConfig.getOutputDir() + "/java.strace");
+      strace.add("-ttt");
+      strace.add("-T");
+      strace.add("-f");
+      strace.add("-ff");
+    }
+
+    strace.addAll(Arrays.asList(command));
+
+    return strace.toArray(new String[0]);
+  }
+
   String[] buildCommand(String rmiHost, int rmiPort, JVMMapping jvmConfig) {
 
-    List<String> command = new ArrayList<String>();
+    List<String> command = new ArrayList<>();
     command.add(System.getProperty("java.home") + "/bin/java");
     command.add("-classpath");
     command.add(jvmConfig.getLibDir() + "/*");
+    command.add("-Djava.library.path=" + System.getProperty("user.home") + "/META-INF/native");
     command.add("-D" + RemoteJVMFactory.RMI_HOST + "=" + rmiHost);
     command.add("-D" + RemoteJVMFactory.RMI_PORT_PROPERTY + "=" + rmiPort);
     command.add("-D" + RemoteJVMFactory.JVM_ID + "=" + jvmConfig.getId());
+    command.add("-D" + RemoteJVMFactory.ROLE + "=" + jvmConfig.getRole());
     command.add("-D" + RemoteJVMFactory.OUTPUT_DIR + "=" + jvmConfig.getOutputDir());
 
-    if (jvmConfig.getJvmArgs().contains("-DwithSsl=true")) {
+    if (jvmConfig.getJvmArgs().contains("-Dbenchmark.withSsl=true")) {
       command
           .add("-Dgemfire." + SSL_KEYSTORE + "=" + jvmConfig.getLibDir() + "/temp-self-signed.jks");
       command.add("-Dgemfire." + SSL_KEYSTORE_PASSWORD + "=123456");
