@@ -21,15 +21,12 @@ import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import org.json.JSONArray;
-import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -77,42 +74,21 @@ public class DefaultTestRunner implements TestRunner {
     }
 
     benchmarkOutput.mkdirs();
-    String metadataFilename = outputDir + "/metadata.json";
-    Path metadataOutput = Paths.get(metadataFilename);
-    JSONObject JSONmetadata = new JSONObject();
+    Properties properties = new Properties();
+    addVersionProperties(properties, getVersionProperties());
+    addSystemProperties(properties);
+    logger.info("Benchmark Properties {}", properties);
 
-    if (metadataOutput.toFile().exists()) {
-      JSONmetadata = new JSONObject(new String(Files.readAllBytes(metadataOutput)));
-    } else {
-      String metadata = System.getProperty("TEST_METADATA");
-      if (!(metadata == null) && !metadata.isEmpty()) {
-        JSONObject testMetadata = new JSONObject();
-        String[] metadataEntries = metadata.split(",");
-        for (String data : metadataEntries) {
-          String[] kv = data.split(":");
-          if (kv.length == 2) {
-            testMetadata.put(kv[0], kv[1]);
-          }
-        }
-        addVersionProperties(testMetadata, getVersionProperties());
-        JSONmetadata.put("testMetadata", testMetadata);
+
+    String metadataFilename = outputDir + "/testrunner.properties";
+    Path metadataOutput = Paths.get(metadataFilename);
+
+    if (!metadataOutput.toFile().exists()) {
+      try (FileWriter writer = new FileWriter(metadataOutput.toFile().getAbsoluteFile())) {
+        properties.store(writer, "Benchmark metadata generated while running tests");
       }
     }
 
-    try {
-      JSONArray testNames = JSONmetadata.getJSONArray("testNames");
-      testNames.put(testName);
-      JSONmetadata.put("testNames", testNames);
-    } catch (org.json.JSONException e) {
-      JSONArray testNames = new JSONArray();
-      testNames.put(testName);
-      JSONmetadata.put("testNames", testNames);
-    }
-
-    FileWriter metadataWriter = new FileWriter(metadataOutput.toFile().getAbsoluteFile());
-    metadataWriter.write(JSONmetadata.toString());
-    metadataWriter.flush();
-
     Map<String, Integer> roles = config.getRoles();
     Map<String, List<String>> jvmArgs = config.getJvmArgs();
 
@@ -132,7 +108,7 @@ public class DefaultTestRunner implements TestRunner {
       // Close before copy otherwise logs, stats, and profiles are incomplete or missing.
       remoteJVMs.closeController();
 
-      logger.info("Copying results...");
+      logger.info("Copying results to {}", benchmarkOutput);
       remoteJVMs.copyResults(benchmarkOutput);
 
       remoteJVMs.closeInfra();
@@ -140,10 +116,16 @@ public class DefaultTestRunner implements TestRunner {
 
   }
 
-  private void addVersionProperties(JSONObject jsonMetadata, Properties versionProperties) {
-    jsonMetadata.put("source_version", versionProperties.getProperty("Product-Version"));
-    jsonMetadata.put("source_branch", versionProperties.getProperty("Source-Repository"));
-    jsonMetadata.put("source_revision", versionProperties.getProperty("Source-Revision"));
+  private void addSystemProperties(Properties properties) {
+    System.getProperties().stringPropertyNames().stream()
+        .filter(name -> name.startsWith("benchmark."))
+        .forEach(name -> properties.setProperty(name, System.getProperty(name)));
+  }
+
+  private void addVersionProperties(Properties jsonMetadata, Properties versionProperties) {
+    jsonMetadata.put("benchmark.source_version", versionProperties.getProperty("Product-Version"));
+    jsonMetadata.put("benchmark.source_branch", versionProperties.getProperty("Source-Repository"));
+    jsonMetadata.put("benchmark.source_revision", versionProperties.getProperty("Source-Revision"));
   }
 
   private Properties getVersionProperties() throws IOException {
@@ -157,6 +139,7 @@ public class DefaultTestRunner implements TestRunner {
   private void runTasks(List<TestStep> steps,
       RemoteJVMs remoteJVMs) {
     steps.forEach(testStep -> {
+      logger.info("Executing task {} on {}...", testStep.getTask(), testStep.getRoles());
       remoteJVMs.execute(testStep.getTask(), testStep.getRoles());
     });
   }
