@@ -17,6 +17,7 @@
 
 package org.apache.geode.perftest;
 
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -26,9 +27,11 @@ import java.nio.file.Path;
 import java.util.function.Predicate;
 import java.util.stream.Stream;
 
+import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
+import org.junitpioneer.jupiter.SetSystemProperty;
 
 import org.apache.geode.perftest.benchmarks.EmptyBenchmark;
 import org.apache.geode.perftest.infrastructure.local.LocalInfrastructureFactory;
@@ -38,19 +41,23 @@ import org.apache.geode.perftest.yardstick.analysis.YardstickThroughputSensorPar
 
 public class TestRunnerIntegrationTest {
 
+  public static final String TEST_PROPERTY = "benchmark.system.all.prop3";
   private TestRunner runner;
 
   @TempDir
   File outputDir;
 
-  public static final String SAMPLE_BENCHMARK = "SampleBenchmark";
-
   @BeforeEach
   void beforeEach() {
     runner = new DefaultTestRunner(new RemoteJVMFactory(new LocalInfrastructureFactory()),
         outputDir);
   }
 
+  @AfterEach()
+  void clearProperty() {
+    System.clearProperty(TEST_PROPERTY);
+  }
+
   @Test
   public void runsBeforeWorkload() throws Exception {
     runner.runTest(() -> {
@@ -92,6 +99,7 @@ public class TestRunnerIntegrationTest {
   }
 
   @Test
+  @SetSystemProperty(key = TEST_PROPERTY, value = "p3")
   public void configuresJVMOptions() throws Exception {
     runner.runTest(() -> {
       TestConfig testConfig = new TestConfig();
@@ -102,6 +110,7 @@ public class TestRunnerIntegrationTest {
             "Expecting system property to be set in launched JVM, but it was not present.");
         assertEquals(5, Integer.getInteger("prop2").intValue(),
             "Expecting system property to be set in launched JVM, but it was not present.");
+        assertThat(System.getProperty("prop3")).isEqualTo("p3");
       }, "all");
       return testConfig;
     });
